const webpack = require('webpack')
const path = require('path')
const merge = require('webpack-merge')
const nodeExternals = require('webpack-node-externals')
const appConfig = require('../utils/get-app-config')
const { projectPath, resolve } = require('../utils')
const baseConfig = require('./webpack.dev.config')

module.exports = merge(baseConfig, {
  mode: 'none',
  devtool: 'inline-cheap-module-source-map',
  externals: [nodeExternals()],
  module: {
    rules: [
      {
        test: /\.js$/,
        loader: 'babel-loader',
        include: [resolve('client'), resolve('test')],
      },
      {
        test: /\.vue$/,
        use: [{
          loader: 'vue-loader',
          options: {
            // 为了统计代码覆盖率，对 vue 文件加入 istanbul-instrumenter-loader
            // preLoaders: {
            //   js: 'istanbul-instrumenter-loader?esModules=true'
            // }
          }
        }]
      },
    ]
  },
  devServer: {
    historyApiFallback: true,
    noInfo: true,
    overlay: true,
  },
  performance: {
    hints: false
  },
  plugins: [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"test"',
        BABEL_ENV: '"test"',
      },
    }),
  ],
})
